@@ -1,4 +1,5 @@
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package main
 
@@ -12,15 +13,15 @@ import (
 	"syscall"
 	"time"
 
-	"github.com/stolostron/multiclusterhub-repo/pkg/config"
-	"github.com/stolostron/multiclusterhub-repo/pkg/repo"
+	"github.com/open-cluster-management/multiclusterhub-repo/pkg/config"
+	"github.com/open-cluster-management/multiclusterhub-repo/pkg/repo"
 )
 
 func main() {
-	c := config.New()
 	log.Printf("Go Version: %s", runtime.Version())
 	log.Printf("Go OS/Arch: %s/%s", runtime.GOOS, runtime.GOARCH)
 
+	c := config.New()
 	server, err := repo.New(c)
 	if err != nil {
 		panic(err)
